/**
 * \file
 *
 * \brief Animation: snake
 * For RGB LED cube 5x5x5
 *
 * \author Anime maker version 1.0 beta
 *
 * Anime maker by: Martin Stejskal (martin.stej@gmail.com)
 *
 */

#include "anim_snake.h"

/* Data format (binary data for framebuffer)
 *     |MSB|           |LSB|MSB|           |LSB|MSB|           |LSB|
 * +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+
 * | 0 | R | R | R | R | R | G | G | G | G | G | B | B | B | B | B |
 * +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+
 *
 * Instruction format (if MSB is 1, then it is possible change some settings)
 *     |MSB|           |LSB|MSB|           |LSB|MSB|           |LSB|
 * +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+
 * | 1 | C | C | C | C | C | C | C | V | V | V | V | V | V | V | V |
 * +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+
 *  C - command (0~127)
 *  V - value   (0~255)
 *
 */
const uint16_t bin_anim_snake[] PROGMEM =
  {  // Serial stream of data
    // Command start of animation + value (slowdown factor)
    cmd_anim_start + 5,
    //Data + other commands (body)
    // Frame 0
    0x1000,0x1000,0x1000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 1
    0x0000,0x1000,0x1000,0x1000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 2
    0x0000,0x0000,0x1000,0x1000,0x1000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 3
    0x0000,0x0000,0x0000,0x1000,0x1000,
    0x0000,0x0000,0x0000,0x0000,0x1000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 4
    0x0000,0x0100,0x0000,0x0000,0x1000,
    0x0000,0x0000,0x0000,0x0000,0x1000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 5
    0x0000,0x0100,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000,0x1000,
    0x0000,0x0000,0x0000,0x1000,0x1000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 6
    0x0000,0x0100,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x1000,0x1000,0x1000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 7
    0x0000,0x0100,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    0x0000,0x1000,0x1000,0x1000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 8
    0x0000,0x0100,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    0x0000,0x3000,0x1000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 9
    0x0000,0x0100,0x0000,0x0000,0x0000,
    0x0000,0x2000,0x0000,0x0000,0x0000,
    0x0000,0x3000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 10
    0x0000,0x2100,0x0000,0x0000,0x0000,
    0x0000,0x2000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 11
    0x0000,0x3100,0x0000,0x0000,0x0000,
    0x0000,0x2000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 12
    0x0000,0x3900,0x0000,0x0000,0x0000,
    0x0000,0x2000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 13
    0x0000,0x3D00,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 14
    0x0000,0x1C00,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0020,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 15
    0x0000,0x0C00,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0000,0x0020,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 16
    0x0000,0x0400,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    0x0000,0x0400,0x0400,0x0020,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 17
    cmd_param_2D_frame + 0,
    0x0000,0x0400,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0400,0x0420,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 18
    cmd_param_2D_frame + 0,
    0x0000,0x0400,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0400,0x0420,0x0400,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 19
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0400,0x0400,0x0420,0x0C00,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 20
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0400,0x0420,0x1C00,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 21
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x0420,0x3C00,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 22
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x0000,0x7C00,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 23
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x4000,0x7800,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 24
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x4000,0x4000,0x7000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 25
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x4000,0x4000,0x4000,0x6000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 26
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x4000,0x4000,0x4000,0x4000,0x4000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 27
    cmd_param_2D_frame + 0,
    0x4000,0x0000,0x0000,0x0000,0x0000,
    0x4000,0x4000,0x4000,0x4000,0x0000,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0080,0x0000,0x0000,
    

    // Frame 28
    0x4000,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    0x4000,0x4000,0x4000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0080,0x0000,0x0000,
    

    // Frame 29
    0x4000,0x4000,0x0000,0x0000,0x0000,
    0x4000,0x0000,0x0000,0x0000,0x0000,
    0x4000,0x4000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0080,0x0000,0x0000,
    

    // Frame 30
    0x4000,0x4000,0x4000,0x0000,0x0000,
    0x4000,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0080,0x0000,0x0000,
    

    // Frame 31
    0x4000,0x4000,0x6000,0x0000,0x0000,
    0x4000,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0080,0x0000,0x0000,
    

    // Frame 32
    0x4000,0x4000,0x7000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0080,0x0000,0x0000,
    

    // Frame 33
    0x0000,0x4000,0x7000,0x0000,0x0000,
    0x0000,0x0000,0x1000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0080,0x0000,0x0000,
    

    // Frame 34
    0x0000,0x0000,0x7000,0x0000,0x0000,
    0x0000,0x0000,0x1000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0080,0x0000,0x0000,
    

    // Frame 35
    0x0000,0x0000,0x3000,0x0000,0x0000,
    0x0000,0x0000,0x1000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    0x0000,0x0000,0x0080,0x0000,0x0000,
    

    // Frame 36
    0x0000,0x0000,0x1000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    0x0000,0x0000,0x1080,0x0000,0x0000,
    

    // Frame 37
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x1000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    0x0000,0x1000,0x1080,0x0000,0x0000,
    

    // Frame 38
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x1000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    0x1000,0x1000,0x1080,0x0000,0x0000,
    

    // Frame 39
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x1000,0x0000,0x0000,
    0x1800,0x1000,0x1080,0x0000,0x0000,
    

    // Frame 40
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x1C00,0x1000,0x1080,0x0000,0x0000,
    

    // Frame 41
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    0x1C00,0x1000,0x0000,0x0000,0x0000,
    

    // Frame 42
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    0x1C00,0x0000,0x0000,0x0000,0x0000,
    

    // Frame 43
    cmd_param_2D_frame + 0,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    0x0C00,0x0000,0x0000,0x0000,0x0000,
    

    // Frame 44
    0x0400,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    

    // Frame 45
    0x0400,0x0480,0x0000,0x0000,0x0000,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 46
    0x0400,0x0480,0x0400,0x0000,0x0000,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 47
    0x0400,0x0480,0x0C00,0x0000,0x0000,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 48
    0x0400,0x0480,0x1C00,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 49
    0x0000,0x1480,0x1C00,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 50
    0x1000,0x1080,0x1C00,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 51
    0x3000,0x1080,0x1800,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 52
    0x7000,0x1080,0x1000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 53
    0x7000,0x1080,0x0000,0x0000,0x0000,
    0x4000,0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0080,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 54
    0x7000,0x0000,0x0000,0x0000,0x0000,
    0x4000,0x0000,0x0000,0x0000,0x0000,
    0x4000,0x0000,0x0000,0x0080,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 55
    0x6000,0x0000,0x0000,0x0000,0x0000,
    0x4000,0x0000,0x0000,0x0000,0x0000,
    0x4000,0x4000,0x0000,0x0080,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 56
    0x4000,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    0x4000,0x4000,0x4000,0x0080,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 57
    cmd_param_2D_frame + 0,
    0x4000,0x0000,0x0000,0x0000,0x0000,
    0x4000,0x4000,0x4000,0x4080,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 58
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x4000,0x4000,0x4000,0x6080,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 59
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x4000,0x4000,0x7080,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 60
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x4000,0x7880,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 61
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x7880,0x0000,
    0x0000,0x0000,0x0000,0x0800,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 62
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x3880,0x0000,
    0x0000,0x0000,0x0000,0x0800,0x0000,
    cmd_param_2D_frame + 1,
    

    // Frame 63
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x1880,0x0000,
    0x0000,0x0000,0x0000,0x0800,0x0000,
    0x0000,0x0000,0x0000,0x0800,0x0800,
    

    // Frame 64
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x0800,0x0000,
    0x0000,0x0000,0x0000,0x0800,0x0800,
    cmd_param_2D_frame + 1,
    

    // Frame 65
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    0x0000,0x0000,0x0000,0x0800,0x0800,
    cmd_param_2D_frame + 1,
    

    // Frame 66
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    0x0000,0x0000,0x0000,0x0800,0x0800,
    

    // Frame 67
    0x0000,0x0000,0x0000,0x0000,0x0800,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    0x0000,0x0200,0x0000,0x0000,0x0800,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    

    // Frame 68
    cmd_param_3D_frame + 1,
    

    // Frame 69
    0x0000,0x0000,0x0000,0x0800,0x0800,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    cmd_param_2D_frame + 1,
    0x0000,0x0200,0x0000,0x0000,0x0800,
    cmd_param_2D_frame + 0,
    

    // Frame 70
    0x0000,0x0000,0x0800,0x0800,0x0800,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    cmd_param_2D_frame + 1,
    0x0000,0x0200,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 71
    0x0000,0x0800,0x0800,0x0800,0x0800,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    cmd_param_2D_frame + 0,
    0x0000,0x0200,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 72
    0x0000,0x1800,0x0800,0x0800,0x0800,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0200,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 73
    0x0000,0x7800,0x0800,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0200,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 74
    0x0000,0x7800,0x0000,0x0000,0x0000,
    0x0000,0x4000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    0x0000,0x0200,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 75
    0x0000,0x7000,0x0000,0x0000,0x0000,
    0x0000,0x4000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    0x0000,0x0200,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 76
    0x0000,0x6000,0x0000,0x0000,0x0000,
    0x0000,0x4000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    0x0000,0x4200,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 77
    0x0000,0x4000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    0x0000,0x4200,0x4000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 78
    cmd_param_2D_frame + 0,
    0x0000,0x4000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    0x0000,0x4200,0x4000,0x4000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 79
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x4000,0x0000,0x0000,0x0000,
    0x0000,0x4200,0x4000,0x4000,0x4000,
    cmd_param_2D_frame + 0,
    

    // Frame 80
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x4200,0x4000,0x4000,0x6000,
    cmd_param_2D_frame + 0,
    

    // Frame 81
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x4000,0x4000,0x7000,
    cmd_param_2D_frame + 0,
    

    // Frame 82
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x4000,0x7800,
    cmd_param_2D_frame + 0,
    

    // Frame 83
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    0x0000,0x0000,0x0000,0x0000,0x7800,
    cmd_param_2D_frame + 0,
    

    // Frame 84
    0x0100,0x0000,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    cmd_param_2D_frame + 1,
    0x0000,0x0000,0x0000,0x0000,0x3800,
    cmd_param_2D_frame + 0,
    

    // Frame 85
    0x0100,0x0000,0x0000,0x0000,0x0800,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    cmd_param_2D_frame + 1,
    0x0000,0x0000,0x0000,0x0000,0x1800,
    cmd_param_2D_frame + 0,
    

    // Frame 86
    0x0100,0x0000,0x0000,0x0800,0x0800,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 87
    0x0100,0x0000,0x0800,0x0800,0x0800,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 88
    0x0100,0x0800,0x0800,0x0800,0x0800,
    0x0000,0x0000,0x0000,0x0000,0x0800,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 89
    0x0900,0x0800,0x0800,0x0800,0x0800,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 90
    0x1900,0x0800,0x0800,0x0800,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 91
    0x3900,0x0800,0x0800,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 92
    0x7900,0x0800,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 93
    0x7900,0x4000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 94
    0x7100,0x4000,0x4000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 95
    0x6100,0x4000,0x4000,0x4000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 96
    0x4000,0x4000,0x4000,0x4000,0x0000,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 97
    0x0000,0x4000,0x4000,0x4000,0x0000,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 98
    0x0000,0x0000,0x4000,0x4000,0x0000,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 99
    0x0000,0x0000,0x4000,0x4000,0x0000,
    0x0000,0x0020,0x0000,0x4000,0x0000,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 100
    0x0000,0x0000,0x0000,0x4000,0x0000,
    0x0000,0x0020,0x0000,0x4000,0x0000,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    0x0000,0x0000,0x0000,0x6000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 101
    cmd_param_2D_frame + 0,
    0x0000,0x0020,0x0000,0x4000,0x0000,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    0x0000,0x0000,0x0000,0x7000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 102
    cmd_param_2D_frame + 0,
    0x0000,0x0020,0x0000,0x0000,0x0000,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    0x0000,0x0000,0x0000,0x7800,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 103
    cmd_param_2D_frame + 0,
    0x0000,0x0020,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x7C00,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 104
    cmd_param_2D_frame + 0,
    0x0000,0x0020,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0400,0x3C00,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 105
    cmd_param_2D_frame + 0,
    0x0000,0x0020,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    0x0000,0x0400,0x0400,0x1C00,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 106
    cmd_param_2D_frame + 0,
    0x0000,0x0020,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0400,0x0C00,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 107
    cmd_param_2D_frame + 0,
    0x0000,0x0420,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0400,0x0400,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 108
    0x0000,0x0400,0x0000,0x0000,0x0000,
    0x0000,0x0420,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0400,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    

    // Frame 109
    0x0000,0x0400,0x0400,0x0000,0x0000,
    0x0000,0x0420,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 110
    0x0000,0x0400,0x0400,0x0400,0x0000,
    0x0000,0x0420,0x0000,0x0000,0x0000,
    0x0000,0x0400,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 111
    0x0000,0x0400,0x0400,0x0C00,0x0000,
    0x0000,0x0420,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 112
    0x0000,0x0400,0x0400,0x1C00,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 113
    0x0000,0x0000,0x0400,0x3C00,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 114
    0x0000,0x0000,0x0000,0x7C00,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 115
    0x0000,0x0000,0x0000,0x7800,0x0000,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    

    // Frame 116
    0x0000,0x0000,0x0000,0x7000,0x0000,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x0040,0x0000,
    

    // Frame 117
    0x0000,0x0000,0x0000,0x6000,0x0000,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    0x0000,0x0000,0x0000,0x0040,0x0000,
    

    // Frame 118
    0x0000,0x0000,0x0000,0x4000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    0x0000,0x0000,0x0000,0x4040,0x0000,
    

    // Frame 119
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    0x0000,0x0000,0x0000,0x6040,0x0000,
    

    // Frame 120
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    cmd_param_2D_frame + 1,
    0x0000,0x0000,0x0000,0x7040,0x0000,
    

    // Frame 121
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x4000,0x0000,
    0x0000,0x0000,0x0000,0x7840,0x0000,
    

    // Frame 122
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0000,0x7C40,0x0000,
    

    // Frame 123
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0000,0x0400,0x3C40,0x0000,
    

    // Frame 124
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0000,0x0400,0x0400,0x1C40,0x0000,
    

    // Frame 125
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0400,0x0400,0x0400,0x0C40,0x0000,
    

    // Frame 126
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    0x0400,0x0400,0x0400,0x0400,0x0000,
    

    // Frame 127
    cmd_param_2D_frame + 0,
    cmd_param_2D_frame + 0,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    0x0400,0x0400,0x0400,0x0000,0x0000,
    

    // Frame 128
    0x0000,0x0001,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 0,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    0x0400,0x0400,0x0400,0x0000,0x0000,
    

    // Frame 129
    0x0000,0x0001,0x0000,0x0000,0x0000,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    0x0400,0x0400,0x0000,0x0000,0x0000,
    

    // Frame 130
    0x0400,0x0001,0x0000,0x0000,0x0000,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    

    // Frame 131
    0x0400,0x0401,0x0000,0x0000,0x0000,
    0x0400,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 132
    cmd_set_pwm_g + 20,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 133
    cmd_set_pwm_r + 240,
    cmd_set_pwm_g + 50,
    cmd_set_pwm_b + 240,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 134
    cmd_set_pwm_r + 220,
    cmd_set_pwm_g + 70,
    cmd_set_pwm_b + 200,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 135
    cmd_set_pwm_r + 200,
    cmd_set_pwm_g + 90,
    cmd_set_pwm_b + 160,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 136
    cmd_set_pwm_r + 180,
    cmd_set_pwm_g + 110,
    cmd_set_pwm_b + 120,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 137
    cmd_set_pwm_r + 160,
    cmd_set_pwm_g + 130,
    cmd_set_pwm_b + 80,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 138
    cmd_set_pwm_r + 140,
    cmd_set_pwm_g + 150,
    cmd_set_pwm_b + 40,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 139
    cmd_set_pwm_r + 120,
    cmd_set_pwm_g + 120,
    cmd_set_pwm_b + 20,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 140
    cmd_set_pwm_r + 100,
    cmd_set_pwm_g + 100,
    cmd_set_pwm_b + 0,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 141
    cmd_set_pwm_r + 75,
    cmd_set_pwm_g + 75,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    
    
    // Frame 142
    cmd_set_pwm_r + 50,
    cmd_set_pwm_g + 50,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,

    
    // Frame 143
    cmd_set_pwm_r + 25,
    cmd_set_pwm_g + 25,
    cmd_set_pwm_b + 0,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    
    
    // Frame 144
    cmd_set_pwm_r + 10,
    cmd_set_pwm_g + 10,
    cmd_set_pwm_b + 0,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    

    // Frame 145
    cmd_set_pwm_r + 0,
    cmd_set_pwm_g + 0,
    cmd_set_pwm_b + 0,
    0x0420,0x0421,0x0000,0x0000,0x0000,
    0x0420,0x0000,0x0000,0x0000,0x0000,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 1,
    cmd_param_2D_frame + 0,
    
    // Frame 146
        // End of animation + option
    cmd_anim_stop + 1
  };