/**
 * \file
 * \brief Anime maker v1.0
 *
 * Anime maker for RGB LED cube 5x5x5
 *
 * \author Martin Stejskal (martin.stej@gmail.com)
 */

/**
 * \brief Version
 */
#define version         "1.0 beta"


#include <stdio.h>      // Standard I/O
#include <stdlib.h>     // Standard library
#include <string.h>     // Library for string operations

#include <inttypes.h>   // Data types

//#include <unistd.h> - if needed sleep function

#include "settings.h"   // Local settings for program

#include "animation_codes.h"    // Animation codes

/*-----------------------------------------*
 |         Function prototypes             |
 *-----------------------------------------*/
void ask_for_anime_name(char *p_animation_name);

int ask_for_slow_down_factor(void);

uint8_t ask_for_pwm(char c_color);


void create_files_and_fill_headers(char *p_animation_name);

void write_start_of_animation(int i_slowdown_factor, char *p_animation_name);

void create_animation(char *p_animation_name, int i_slowdown_factor);

void write_end_of_animation(int i_options, char *p_animation_name);

void write_frame(uint8_t  (*p_fb_data_virtual)[5][5][5],
                 uint16_t (*p_anim_stream)[max_size_anim_stream],
                 uint16_t (*p_commands),
                 uint32_t i_frame);


void write_content_to_file(uint16_t (*p_anim_stream)[max_size_anim_stream],
                           uint32_t i_frame,
                           char *p_animation_name);


void jump_out_to_next_screen(void);

void clear_virtual_framebuffer(uint8_t (*p_fb_data_vitual)[5][5][5]);

void set_virtual_framebuffer(uint8_t (*p_fb_data_virtual)[5][5][5]);



void clear_real_framebuffer(uint16_t (*p_anim_stream)[max_size_anim_stream]);

void show_preview(uint8_t  (*p_fb_data_virtual)[5][5][5],
                  uint32_t i_frame_counter,
                  uint8_t  i_wall,
                  uint8_t  i_column,
                  uint8_t  i_led_level,
                  uint8_t  i_pwm_r,
                  uint8_t  i_pwm_g,
                  uint8_t  i_pwm_b,
                  float f_virtual_time);


/**
 * \brief Main program structure
 * @return 0 if all OK
 */
int main(void)
{

  char c_animation_name[name_len];      // Variable for animation name

  int  i_slowdown_factor;               // Slowdown factor

  // Ask for name of animation
  ask_for_anime_name( c_animation_name );

  // Create new animation file and fill headers
  create_files_and_fill_headers( c_animation_name );

  // Load slowdown factor
  i_slowdown_factor = ask_for_slow_down_factor();

  // Write start of animation
  write_start_of_animation( i_slowdown_factor, c_animation_name );

  // Create body of animation
  create_animation( c_animation_name, i_slowdown_factor );

  // End of animation
  write_end_of_animation(1, c_animation_name);

  /*
  int  dec = 32768;

  printf("\n HEX: %X | DEC: %d\n\n", dec, dec);
*/

  return(no_error);
}









/**
 * \brief Ask user for animation name and save it
 *
 * Data are saved thru pointer.
 *
 * @param p_animation_name Pointer to text array where animation name is saved
 */
void ask_for_anime_name(char *p_animation_name){
  printf(""
"+---------------------------------------------------------------------------+"
"\n"
"| Hello and welcome! This is simple animation maker for RGB 5x5x5 LED cube. |"
"\n"
"| First i need to know name for your animation, so please type animation    |"
"\n"
"| name. Please DO NOT USE spaces!                                           |"
"\n"
"+---------------------------------------------------------------------------+"
"\n| Animation name: ");

  // get animation name
  int status = 0;
  // Load data from keyboard
  status = scanf("%s", p_animation_name );

  if( status != 1)    // If problem...
  {
    printf(""
"| !! Sorry, this can not be used as animation name :(                       |"
"\n"
"+xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx+"
"\n");

    exit( incorrect_input );
  }

  printf(""
"+---------------------------------------------------------------------------+"
"\n");
}






int ask_for_slow_down_factor(void)
{
  int i_slowdown_factor = 0;

  printf(""
"| OK, now we need slowdown factor. Normally LED cube produce 25 fps. That   |"
"\n"
"| means we need 25 frames for 1 second. However, sometimes is not need to   |"
"\n"
"| have 25 fps. And for this is slowdown factor. If is set to 1, then LED    |"
"\n"
"| cube produce 25 fps. If is set to 2, then 12.5 fps and so on. Maximum     |"
"\n"
"| value should not exceed 255. So please type slowdown factor.              |"
"\n"
"+---------------------------------------------------------------------------+"
"\n| Slowdown factor: "
  );

  int status = 0;

  // Read data from keyboard as text... Little bit bigger then needed
  char c_input_data[default_text_len];

  while( status != 1 )  // Until name is not valid (one item)
  {
    // Load data from keyboard as string
    status = scanf("%s", c_input_data);

    status = 1; // Set status to 1 - so far no problem

    int i;
    // Scan input data - test if it is number, or not
    for(i=0 ; i<default_text_len ; i++)
    {   /* Test character - if null (last character) -> break -> in "i" is
         * length
         */
      if( c_input_data[i] == '\0' )
      {
        // Test if length is not zero
        if( i == 0)
        {       // If length is zero -> not a number
          status = 1;
        }
        break;
      }
      // Test character - if found anything else than 0~9 -> set status to "0"
      if( (c_input_data[i]<'0') || (c_input_data[i]>'9'))
      {
        status = 0;
      }
    }

    if( status != 1 )   // If problem
    {
      printf(""
"| !! Sorry. this is not valid number. Please type number from 1 to 255      |"
"\n"
"| Slowdown factor: ");
    }
    else
    {   // If there was no problem -> calculate input number
      int i_mul = 1;            // Multiplier for calculation
      i_slowdown_factor = 0;    // Restart slowdown factor

      /* Load numbers backward, so it will be easy to calculate them. Variable
       * "i" is used as counter from last for cycle
       */
      for(i=i-1 ; i>=0 ; i--)
      {
        /* Calculate value of actual "number" stored in text array and add it
         * to previous result
         */
        i_slowdown_factor = i_slowdown_factor +
                            i_mul * ((c_input_data[i])-'0');
        i_mul = i_mul * 10;     // Multiply multiplier by 10 (decade)
      }
    }
  }






  // If user type number out of scale
  if( i_slowdown_factor <= 0 )
  {     // If smaller than limit
    i_slowdown_factor = 1;      // Set minimum
    printf(""
"| ! Warning: Slowdown factor can not be smaller than 1 -> set to 1.         |"
"\n"
    );
  }




  if( i_slowdown_factor > 255 )
  {
    i_slowdown_factor = 255;
    printf(""
"| ! Warning: Slowdown factor can not be greater than 255 -> set to 255.     |"
"\n"
    );
  }

  return i_slowdown_factor;
}









uint8_t ask_for_pwm(char c_color)
{
  uint8_t i_pwm_value = 0;

  // Just because of warning with scanf
  uint8_t status;

  // Decide according color
  switch(c_color)
  {
  case 'R': printf("| PWM - RED - value: "); break;
  case 'r': printf("| PWM - RED - value: "); break;
  case 'G': printf("| PWM - GREEN - value: "); break;
  case 'g': printf("| PWM - GREEN - value: "); break;
  case 'B': printf("| PWM - BLUE - value: "); break;
  case 'b': printf("| PWM - BLUE - value: "); break;
  default: printf("| PWM - value: ");
  }


  // For saving value - bigger than needed - because of dummy user
  char c_value[15];

  // Scan input until there will not be valid data
  while(1)
  {
    status = scanf("%s", c_value);      // Load new value
    if(status == 0)     // If something is wrong
    {
      printf("\nPruser\n");
      c_value[0]='\0';  // Set first character to NULL -> not a number
    }


    /* Maximum value can be set to 255 -> scan just first 3 bytes for null
     * character. If not found -> presume length is 3 digits and other
     * bytes throw
     */
    // Test if it could be number, or just dummy string
    if( (c_value[0]>='0' || c_value[0]<='9') &&
        (c_value[1]>='0' || c_value[1]<='9') &&
        (c_value[2]>='0' || c_value[2]<='9') )
    {
      // Test if "second" character is NULL and first is number
      if(c_value[1]=='\0')
      {// In this case is length 1 -> easy to calculate
        // Create command -> command number + value
        // (ASCII value - ASCII number for 0)
        i_pwm_value = (c_value[0]-'0');
        break;
      }
      else if(c_value[2]=='\0')
      {// Little bit tricky. First load [0] - 10x and then [1] - 1x
        i_pwm_value =                10 * (c_value[0]-'0');
        i_pwm_value = i_pwm_value +       (c_value[1]-'0');
        break;      // Go out of the while (data valid)
      }
      else
      {// Else assume that there is only 3 digit number
        i_pwm_value =               100 * (c_value[0]-'0');     // 100x
        i_pwm_value = i_pwm_value +  10 * (c_value[1]-'0');     // 10x
        i_pwm_value = i_pwm_value +       (c_value[2]-'0');     // 1x

        // Test if i_pwm_value
        if(i_pwm_value > 255)
        {
          printf(""
"| ! Warning: PWM value can not be greater than 255 -> set 255.              |"
"\n");
        }
        break;
    }

    }
    // If not possibly number -> printf message
    printf(""
"| !! Sorry. this is not valid number. Please type number from 1 to 255      |"
"\n");

    // And print something extra depends on color
    // Decide according color
    switch(c_color)
    {
    case 'R': printf("\n| PWM - RED - value: "); break;
    case 'r': printf("\n| PWM - RED - value: "); break;
    case 'G': printf("\n| PWM - GREEN - value: "); break;
    case 'g': printf("\n| PWM - GREEN - value: "); break;
    case 'B': printf("\n| PWM - BLUE - value: "); break;
    case 'b': printf("\n| PWM - BLUE - value: "); break;
    default: printf("\n| PWM - value: ");
    }
  }// End while


  return i_pwm_value;
}








/**
 * \brief Create new files in "generated_anime_folder" and write headers
 *
 * Create files named by animation_name and write some common data.
 *
 * @param p_animation_name Pointer to text array where animation name is saved
 */
void create_files_and_fill_headers(char *p_animation_name)
{
  FILE *file;   // Pointer to file

  // String for complete path (include filename and extension -> +2)
  char c_file_and_path[name_len + path_len +2];


  // Save string contains name of anime folder
  strcpy(c_file_and_path, generated_anime_folder);
  // Add slash and prefix anim
  strcat(c_file_and_path, "/anim_");
  // Add file name
  strcat(c_file_and_path, p_animation_name);
  // Add ".h"
  strcat(c_file_and_path, ".h");

  // Open file - .h file (overwrite mode)
  file = fopen( c_file_and_path, "w+");

  char c_file_content[3000];

  // OK, now fill content for .h file
  strcpy(c_file_content, "\
/**\n\
 * \\file\n\
 *\n\
 * \\brief Animation: ");
  // Add animation name
  strcat(c_file_content, p_animation_name);
  strcat(c_file_content, "\n * For RGB LED cube 5x5x5\n *\n");
  // Version
  strcat(c_file_content,
" * \\author Anime maker version ");
  strcat(c_file_content, version);

  strcat(c_file_content, "\n *\n"
" * Anime maker by: Martin Stejskal (martin.stej@gmail.com)\n"
" *\n\
 */\n\
\n\
#ifndef _anim_");
  strcat(c_file_content, p_animation_name);
  strcat(c_file_content, "_library_\n#define _anim_");
  strcat(c_file_content, p_animation_name);
  strcat(c_file_content, "_library_\n\n"
"/*-----------------------------------------*\n"
" |               Includes                  |\n"
" *-----------------------------------------*/\n"
"#include <avr/pgmspace.h>       // For operations with flash memory\n"
"#include <inttypes.h>           // Data types\n"
"\n"
"#include \"animation_codes.h\"    // For more \"human read\" animation code\n"
"\n"
"extern const uint16_t bin_anim_");
  strcat(c_file_content, p_animation_name);
  strcat(c_file_content, "[];\n"
"\n"
"#endif\n");

  // Write content to file
  fprintf(file, "%s", c_file_content);

  // Close .h file
  fclose(file);






  // Save string contains name of anime folder
  strcpy(c_file_and_path, generated_anime_folder);
  // Add slash and prefix anim
  strcat(c_file_and_path, "/anim_");
  // Add file name
  strcat(c_file_and_path, p_animation_name);
  // Add ".c"
  strcat(c_file_and_path, ".c");

  // Open file - .c file (overwrite mode)
  file = fopen( c_file_and_path, "w+");

  // OK, now fill content for .c file
  strcpy(c_file_content, "\
/**\n\
 * \\file\n\
 *\n\
 * \\brief Animation: ");
  // Add animation name
  strcat(c_file_content, p_animation_name);
  strcat(c_file_content, "\n * For RGB LED cube 5x5x5\n *");
  // Version
  strcat(c_file_content, "\n\
 * \\author Anime maker version ");
  strcat(c_file_content, version);

  strcat(c_file_content, "\n *\n"
" * Anime maker by: Martin Stejskal (martin.stej@gmail.com)\n"
" *\n"
" */\n"
"\n"
"#include \"anim_");
  strcat(c_file_content, p_animation_name);
  strcat(c_file_content, ".h\"\n"
"\n"
"/* Data format (binary data for framebuffer)\n"
" *     |MSB|           |LSB|MSB|           |LSB|MSB|           |LSB|\n"
" * +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n"
" * | 0 | R | R | R | R | R | G | G | G | G | G | B | B | B | B | B |\n"
" * +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n"
" *\n"
" * Instruction format (if MSB is 1, then it is possible change some settings)"
"\n *     |MSB|           |LSB|MSB|           |LSB|MSB|           |LSB|\n"
" * +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n"
" * | 1 | C | C | C | C | C | C | C | V | V | V | V | V | V | V | V |\n"
" * +---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+---+\n"
" *  C - command (0~127)\n"
" *  V - value   (0~255)\n"
" *\n"
" */\n"
"const uint16_t bin_anim_");

  strcat(c_file_content, p_animation_name);
  strcat(c_file_content, "[] PROGMEM =\n  {  // Serial stream of data\n");

  // Write content to file
  fprintf(file, "%s", c_file_content);

  // Close .c file
  fclose(file);
}




/**
 * \brief Write start of animation code to file with animation
 * @param i_slowdown_factor Slowdown factor for animation
 * @param p_animation_name Pointer to text array where animation name is saved
 */
void write_start_of_animation(int i_slowdown_factor, char *p_animation_name)
{
  // Test for input parameters
  if( (i_slowdown_factor > 255) || (i_slowdown_factor < 0))
  {
    i_slowdown_factor = 0;      // If input variable is out of range
    printf(""
"| ! Warning: i_slowdown_factor out of range. Set to 0 (default)             |"
"\n"
        );
  }


  FILE *file;   // Pointer to file

  // String for complete path (include filename and extension -> +2)
  char c_file_and_path[name_len + path_len +2];


  // Save string contains name of anime folder
  strcpy(c_file_and_path, generated_anime_folder);
  // Add slash and prefix anim
  strcat(c_file_and_path, "/anim_");
  // Add file name
  strcat(c_file_and_path, p_animation_name);
  // Add ".c"
  strcat(c_file_and_path, ".c");

  // Open file - .c file (append mode)
  file = fopen( c_file_and_path, "a+");

  char c_file_content[256];

  strcpy(c_file_content, ""
"    // Command start of animation + value (slowdown factor)\n"
"    cmd_anim_start + "
  );

  // Transform i_slowdown_factor to string number
  char c_number_as_text[4];
  sprintf( c_number_as_text, "%d", i_slowdown_factor);

  strcat(c_file_content, c_number_as_text);
  strcat(c_file_content, ",\n    //Data + other commands (body)\n");

  // Write content to file
  fprintf(file, "%s", c_file_content);

  fclose(file);
}









void create_animation(char *p_animation_name, int i_slowdown_factor)
{
  // Info for user
  printf(""
"+---------------------------------------------------------------------------+"
"\n"
"| So, now i enable creative mode ;) There you can build your own animation. |"
"\n"
"| Ready? If yes, then enter                                                 |"
"\n"
"+---------------------------------------------------------------------------+"
"\n"
  );

  getchar();    // Before flush must be read, else not work as expected
  fflush(stdin);// Clean input buffer

  char c_pressed_key = '\0';

  // Wait until any key pressed
  while( c_pressed_key == '\0')
  {
    c_pressed_key = getchar();
  }


  // Create some variables
  uint32_t i_frame_counter = 0;             // Counts whole frames
  uint8_t i_wall = 0;                      // Number of active "wall" on LED cube
  uint8_t i_column = 0;                    // Active column on LED cube

  uint8_t i_pwm_r = 255;                   // PWM value for red LEDs
  uint8_t i_pwm_g = 255;                   // PWM value for green LEDs
  uint8_t i_pwm_b = 255;                   // PWM value for blue LEDs

  float f_virtual_time = 0;             // Virtual time of animation

  uint8_t i_led_level = 4;                // Highest LED

  // Virtual framebuffer (just for preview)
  // [wall][led level][column]
  uint8_t i_fb_data_virtual[5][5][5];

  // "Real" stream for LED cube
  uint16_t i_anim_stream[max_size_anim_stream];

  // Clear virtual framebuffer
  clear_virtual_framebuffer( &i_fb_data_virtual );

  // Clear real framebuffer
  clear_real_framebuffer( &i_anim_stream );

  // Array for commands (per whole frame)
  uint16_t i_commands[max_commands_per_frame];

  // Clear first in array
  i_commands[0] = 0;    // No command so far

  // Index for counting commands
  uint8_t i_command_index = 0;

  // Status variable
  int status = 0;

  // Text array for command
  char c_cmd[max_command_length];


  int animation_done = 0;
  // Wait until animation is done
  while( animation_done == 0 )
  {
    // Clear screen
    jump_out_to_next_screen();
    // Show actual data
    show_preview( &i_fb_data_virtual,
                  i_frame_counter,
                  i_wall,
                  i_column,
                  i_led_level,
                  i_pwm_r,
                  i_pwm_g,
                  i_pwm_b,
                  f_virtual_time);

    // Clear - for case that previous command will be shorter than 3 characters
    for(int i=0 ; i<max_command_length ; i++)
    {
      c_cmd[i] = '\0';
    }

    status = scanf("%s", c_cmd);
    // OK, let's test for possible commands


    // EXIT
    if( (strcmp(c_cmd,"exit")==0) ||
        (strcmp(c_cmd,"Exit")==0) ||
        (strcmp(c_cmd,"EXIT")==0) ||
        (strcmp(c_cmd,"e")   ==0) )
    {// Exit - everything is done. Just break while condition
      animation_done = 1;
    }

    // ZEROS
    if( (strcmp(c_cmd,"zeros")==0) ||
        (strcmp(c_cmd,"Zeros")==0) ||
        (strcmp(c_cmd,"ZEROS")==0) )
    {
      status = pressed_button;  // Do not change position of cursor
      for(int j=0 ; j<5 ; j++)
      {
        for(int k=0 ; k<5 ; k++)
        {
          i_fb_data_virtual[i_wall][j][k] = 0;
        }
      }
    }

    // ONES
    if( (strcmp(c_cmd,"ones")==0) ||
        (strcmp(c_cmd,"Ones")==0) ||
        (strcmp(c_cmd,"ONES")==0) )
    {
      status = pressed_button;  // Do not change position of cursor
      for(int j=0 ; j<5 ; j++)
      {
        for(int k=0 ; k<5 ; k++)
        {
          i_fb_data_virtual[i_wall][j][k] = (1<<red_shift)|
                                            (1<<green_shift)|
                                            (1<<blue_shift);
        }
      }
    }

    // PWM red
    if( (strcmp(c_cmd,"pwmr")==0) ||
        (strcmp(c_cmd,"Pwmr")==0) ||
        (strcmp(c_cmd,"PWMR")==0) )
    {// And ask for value
      i_pwm_r = ask_for_pwm('R');
      // And create command
      i_commands[i_command_index++] = cmd_set_pwm_r + i_pwm_r;
    }

    // PWM green
    if( (strcmp(c_cmd,"pwmg")==0) ||
        (strcmp(c_cmd,"Pwmg")==0) ||
        (strcmp(c_cmd,"PWMG")==0) )
    {// And ask for value
      i_pwm_g = ask_for_pwm('G');
      // And create command
      i_commands[i_command_index++] = cmd_set_pwm_g + i_pwm_g;
    }

    // PWM blue
    if( (strcmp(c_cmd,"pwmb")==0) ||
        (strcmp(c_cmd,"Pwmb")==0) ||
        (strcmp(c_cmd,"PWMB")==0) )
    {// And ask for value
      i_pwm_b = ask_for_pwm('B');
      // And create command
      i_commands[i_command_index++] = cmd_set_pwm_b + i_pwm_b;
    }

    // LINE
    if( (strcmp(c_cmd,"line")==0) ||
        (strcmp(c_cmd,"Line")==0) ||
        (strcmp(c_cmd,"LINE")==0) ||
        (strcmp(c_cmd,"l")   ==0) )
    {
      status = pressed_button;  // Do not change position of cursor

      // Grab actual segment and copy it
      uint8_t i_segment = i_fb_data_virtual[i_wall][i_led_level][i_column];
      // And copy it thru actual 2D frame
      for(int i=0 ; i<5 ; i++)
      {
        i_fb_data_virtual[i_wall][i_led_level][i] = i_segment;
      }
    }

    // COLUMN
    if( (strcmp(c_cmd,"column")==0) ||
        (strcmp(c_cmd,"Column")==0) ||
        (strcmp(c_cmd,"COLUMN")==0) ||
        (strcmp(c_cmd,"c")     ==0) )
    {
      status = pressed_button;  // Do not change position of cursor

      // Grab actual segment and copy it
      uint8_t i_segment = i_fb_data_virtual[i_wall][i_led_level][i_column];
      // And copy it thru actual 2D frame
      for(int i=0 ; i<5 ; i++)
      {
        i_fb_data_virtual[i_wall][i][i_column] = i_segment;
      }
    }


    // ARROW UP
    if( c_cmd[0]==27 && c_cmd[1]==91 && c_cmd[2]==65 && c_cmd[3]==0)
    {
      // Signalizes, that button was pressed
      status = pressed_button;

      i_led_level++;    // Increase LED level
      if(i_led_level>4) // If greater than 4 (should not be)
      {
        i_led_level=0;  // Set to zero
      }
    }

    // ARROW DOWN
    if( c_cmd[0]==27 && c_cmd[1]==91 && c_cmd[2]==66 && c_cmd[3]==0)
    {
      // Signalizes, that button was pressed
      status = pressed_button;

      i_led_level--;    // Decrease LED level
      if(i_led_level==255) // If smaller than 0 (should not be)
      {
        i_led_level=4;  // Set to highest level again
      }
    }

    // ARROW RIGHT
    if( c_cmd[0]==27 && c_cmd[1]==91 && c_cmd[2]==67 && c_cmd[3]==0)
    {
      // Signalizes, that button was pressed
      status = pressed_button;

      i_column++;
      if(i_column>4)
      {
        i_column = 0;
      }
    }

    // ARROW LEFT
    if( c_cmd[0]==27 && c_cmd[1]==91 && c_cmd[2]==68 && c_cmd[3]==0)
    {
      // Signalizes, that button was pressed
      status = pressed_button;

      i_column--;
      if(i_column==255)
      {
        i_column = 4;
      }
    }

    // NEXT (2D frame - wall)
    if( (strcmp(c_cmd,"next")==0) ||
        (strcmp(c_cmd,"Next")==0) ||
        (strcmp(c_cmd,"NEXT")==0) ||
        (strcmp(c_cmd,"n")   ==0) )
    {
      // Signalizes, that button was pressed
      status = pressed_button;

      i_column = 0;
      i_led_level = 4;
      i_wall++;       // Move to next wall
      // And check wall
      if(i_wall>4)
      {
        i_commands[i_command_index] = 0;    // On the last position write 0
        // And load data to "real buffer"
        write_frame(&i_fb_data_virtual,
                    &i_anim_stream,
                    i_commands,
                    i_frame_counter);

        i_command_index = 0;    // After write reset
        i_wall=0;
        i_frame_counter++;    // Next frame -> increase
        // Recalculate time
        f_virtual_time = f_virtual_time + (frame_period*i_slowdown_factor);
      }
    }

    // BACK (2D frame - wall)
    if( (strcmp(c_cmd,"back")==0) ||
        (strcmp(c_cmd,"Back")==0) ||
        (strcmp(c_cmd,"BACK")==0) ||
        (strcmp(c_cmd,"m")   ==0) )
    {
      // Signalizes, that button was pressed
      status = pressed_button;

      i_column = 0;
      i_led_level = 4;
      i_wall--;         // Move to previous wall
      // And check wall
      if(i_wall>4)
      {
        i_wall = 0;
        /**
         * \todo Complete back function (even for 3D frames)
         */
      }
    }












    // DATA - global - test if there is at least one combination
    if(((c_cmd[0]=='A' || c_cmd[0]=='a' || c_cmd[0]=='1' ||
         c_cmd[0]=='R' || c_cmd[0]=='G' || c_cmd[0]=='B' ||
         c_cmd[0]=='r' || c_cmd[0]=='g' || c_cmd[0]=='b' ||
         c_cmd[0]=='0' || c_cmd[0]=='-') ||

        (c_cmd[1]=='1' ||
         c_cmd[1]=='R' || c_cmd[1]=='G' || c_cmd[1]=='B' ||
         c_cmd[1]=='r' || c_cmd[1]=='g' || c_cmd[1]=='b' ||
         c_cmd[1]=='0' || c_cmd[1]=='-') ||

         (c_cmd[2]=='1' ||
          c_cmd[2]=='R' || c_cmd[2]=='G' || c_cmd[2]=='B' ||
          c_cmd[2]=='r' || c_cmd[2]=='g' || c_cmd[2]=='b' ||
          c_cmd[2]=='0' || c_cmd[2]=='-')) &&

          // If some arrow pressed, then there can be symbol A,B,C or D, so...
         ( status != pressed_button ) &&
         ( c_cmd[0]!=27 ) && (c_cmd[1]!=91) && (c_cmd[3]!=27) && (c_cmd[4]!=91)
         &&
         (c_cmd[0]!='\0'))
    {
      // Write data to buffer
      i_fb_data_virtual[i_wall][i_led_level][i_column] = 0;     // Set to 0

      // And now add data
      // Test if was set red color
      if( c_cmd[0]=='r' || c_cmd[0]=='R' || c_cmd[0]=='a' || c_cmd[0]=='A' ||
          c_cmd[1]=='r' || c_cmd[1]=='R' || c_cmd[0]=='1' ||
          c_cmd[2]=='r' || c_cmd[2]=='R' )
      {// If was set red bit -> add it
        i_fb_data_virtual[i_wall][i_led_level][i_column] |= (1<<red_shift);
      }

      // Test for "green bit"
      if( c_cmd[0]=='g' || c_cmd[0]=='G' || c_cmd[0]=='a' || c_cmd[0]=='A' ||
          c_cmd[1]=='g' || c_cmd[1]=='G' || c_cmd[1]=='1' ||
          c_cmd[2]=='g' || c_cmd[2]=='G' )
      {// If was set red bit -> add it
        i_fb_data_virtual[i_wall][i_led_level][i_column] |= (1<<green_shift);
      }
      // And test for "blue bit"
      if( c_cmd[0]=='b' || c_cmd[0]=='B' || c_cmd[0]=='a' || c_cmd[0]=='A' ||
          c_cmd[1]=='b' || c_cmd[1]=='B' || c_cmd[2]=='1' ||
          c_cmd[2]=='b' || c_cmd[2]=='B' )
      {// If was set red bit -> add it
        i_fb_data_virtual[i_wall][i_led_level][i_column] |= (1<<blue_shift);
      }





      // Change index only if was not pressed any arrow button
      if( status != pressed_button )
      {
        // Change index
        i_column++;       // Increase column number
      }


      if(i_column>4)
      {
        i_column=0;     // Set to "first" colummn

        i_led_level--;    // Decrease LED level
        if(i_led_level==255) // If smaller than 0 (should not be)
        {
          i_led_level=4;  // Set to highest level again
          i_wall++;       // Move to next wall
          // And check wall
          if(i_wall>4)
          {
            i_commands[i_command_index] = 0;    // On the last position write 0
            // And load data to "real buffer"
            write_frame(&i_fb_data_virtual,
                        &i_anim_stream,
                        i_commands,
                        i_frame_counter);

            i_wall=0;

            i_command_index = 0;    // After write reset command index

            i_frame_counter++;    // Next frame -> increase
            // Recalculate time
            f_virtual_time = f_virtual_time + (frame_period*i_slowdown_factor);
          }
        }
      }
    }


  }




  // OK, now write data to file
  write_content_to_file( &i_anim_stream, i_frame_counter, p_animation_name);

  // String for complete path (include filename and extension -> +2)
  char c_file_and_path[name_len + path_len +2];

  // Save string contains name of anime folder
  strcpy(c_file_and_path, generated_anime_folder);
  // Add slash and prefix anim
  strcat(c_file_and_path, "/anim_");
  // Add file name
  strcat(c_file_and_path, p_animation_name);


  printf(""
"+---------------------------------------------------------------------------+"
"\n"
"| Your animation files are:                                                 |"
"\n"
"| ./%s.c\n| ./%s.h\n"
"+---------------------------------------------------------------------------+"
"\n"
"                                   BYE!\n"
  ,c_file_and_path, c_file_and_path);

}






/**
 * \brief Write actual frame (3D) to data stream
 *
 * @param p_fb_data_virtual Pointer do virtual framebuffer
 * @param p_anim_stream Pointer to serial data stream
 * @param i_frame Inform where continue
 */
void write_frame(uint8_t  (*p_fb_data_virtual)[5][5][5],
                 uint16_t (*p_anim_stream)[max_size_anim_stream],
                 uint16_t (*p_commands),
                 uint32_t i_frame)
{
  // Counts columns. If reached 25 (overflow) -> one frame
  uint8_t  i_column_cnt = 0;

  // Counts found fames
  uint32_t i_actual_frame = 0;

  // Counter for stream index
  uint64_t i_index_cnt = 0;

  // Loaded word from stream
  uint16_t i_anime_word;

  // First we need to find where to continue write data
  while( (i_actual_frame < i_frame) & (i_frame != 0) )
  {
    // Load first anime_word
    i_anime_word = (*p_anim_stream)[i_index_cnt];

    // Increase counter (next time load following word)
    i_index_cnt++;

    // Test if i_anime_word is data (increase i_column_cnt) or command
    if( (i_anime_word & 0x8000)==0 )
    {// If data -> increase i_column_cnt
      i_column_cnt++;

      // Ok, test if i_column_cnt is not 25 -> overflow -> next frame
      if(i_column_cnt == 25)
      {
        // If yes, then restart i_column_cnt
        i_column_cnt = 0;

        // And increase i_actual_frame
        i_actual_frame++;
      }

    }
    // Else command do nothing
  }

  // OK, if we are out of while, then we add data from framebuffer
  i_anime_word = (*p_commands);      // Load first command


  // First write commands - write until there are commands
  while( (i_anime_word & 0x8000) != 0 )
  {
    (*p_anim_stream)[i_index_cnt] = i_anime_word;
    i_index_cnt++;

    // Increase pointer;
    p_commands++;
    // And load next command
    i_anime_word = (*p_commands);
  }

  // Now data
  for(int i=0 ; i<5 ; i++)      // Walls
  {
    for(int j=0 ; j<5 ; j++)    // Columns
    {
      // Clear variable
      i_anime_word = 0;

      for(int k=0 ; k<5 ; k++)  // LED level
      {
        // Red Color
        i_anime_word |=                                 // Add data
            (((*p_fb_data_virtual)[i][k][j]) & (0b100)) // Masking
              <<((red_shift*5)+k-red_shift);            // And bit shift

        // Red Green
        i_anime_word |=                                 // Add data
            (((*p_fb_data_virtual)[i][k][j]) & (0b010)) // Masking
              <<((green_shift*5)+k-green_shift);        // And bit shift

        // Red Blue
        i_anime_word |=                                 // Add data
            (((*p_fb_data_virtual)[i][k][j]) & (0b001)) // Masking
              <<((blue_shift*5)+k-blue_shift);          // And bit shift
      }

      // Write 16 bits
      (*p_anim_stream)[i_index_cnt++] = i_anime_word;
    }
  }
}


/**
 * \brief Write data from p_anim_stream to file
 *
 * @param p_anim_stream Pointer to serial data stream
 * @param i_frame Inform where abort reading from stream (frame counter)
 * @param p_animation_name Pointer to p_animation_name. Need for file\n
 *  modification
 */
void write_content_to_file(uint16_t (*p_anim_stream)[max_size_anim_stream],
                           uint32_t i_frame,
                           char *p_animation_name)
{
  // Open file...
  FILE *file;   // Pointer to file

  // String for complete path (include filename and extension -> +2)
  char c_file_and_path[name_len + path_len +2];

  // Save string contains name of anime folder
  strcpy(c_file_and_path, generated_anime_folder);
  // Add slash and prefix anim
  strcat(c_file_and_path, "/anim_");
  // Add file name
  strcat(c_file_and_path, p_animation_name);
  // Add ".c"
  strcat(c_file_and_path, ".c");

  // Open file - .c file (append mode)
  file = fopen( c_file_and_path, "a+");


  // Temporary text string (for writing "one line")
  char c_tmp_txt[512];

  fprintf(file, "    // Frame 0\n    "); // Write to file


  // Temporary string for transformation integer to string
  char c_tmp_num[10];

  // Counts written frame
  uint32_t i_actual_frame = 0;

  // Counts actual wall
  uint8_t  i_actual_wall = 0;

  // Counts actual column
  uint8_t  i_actual_column = 0;

  // Counts words in p_anim_stream (used index)
  uint64_t i_word_index = 0;

  // Word read from anime stream
  uint16_t i_anime_word;

  /* Inform if there were made any frame compression thru command -> if yes,
   * then do not test for other compression
   */
  uint8_t i_command_created = 0;

  /* Write frame-by-frame (include special commands) - until all frames are
   * written
   */
  while( i_actual_frame < i_frame )
  {
    // Read word
    i_anime_word = (*p_anim_stream)[i_word_index];

    // No command was created. At least for this cycle....
    i_command_created = 0;


    /* Test if actual 3D frame is void. If yes, then create special command.
     */
    if( (*p_anim_stream)[i_word_index+ 0] == 0 &&
        (*p_anim_stream)[i_word_index+ 1] == 0 &&
        (*p_anim_stream)[i_word_index+ 2] == 0 &&
        (*p_anim_stream)[i_word_index+ 3] == 0 &&
        (*p_anim_stream)[i_word_index+ 4] == 0 &&
        (*p_anim_stream)[i_word_index+ 5] == 0 &&
        (*p_anim_stream)[i_word_index+ 6] == 0 &&
        (*p_anim_stream)[i_word_index+ 7] == 0 &&
        (*p_anim_stream)[i_word_index+ 8] == 0 &&
        (*p_anim_stream)[i_word_index+ 9] == 0 &&
        (*p_anim_stream)[i_word_index+10] == 0 &&
        (*p_anim_stream)[i_word_index+11] == 0 &&
        (*p_anim_stream)[i_word_index+12] == 0 &&
        (*p_anim_stream)[i_word_index+13] == 0 &&
        (*p_anim_stream)[i_word_index+14] == 0 &&
        (*p_anim_stream)[i_word_index+15] == 0 &&
        (*p_anim_stream)[i_word_index+16] == 0 &&
        (*p_anim_stream)[i_word_index+17] == 0 &&
        (*p_anim_stream)[i_word_index+18] == 0 &&
        (*p_anim_stream)[i_word_index+19] == 0 &&
        (*p_anim_stream)[i_word_index+20] == 0 &&
        (*p_anim_stream)[i_word_index+21] == 0 &&
        (*p_anim_stream)[i_word_index+22] == 0 &&
        (*p_anim_stream)[i_word_index+23] == 0 &&
        (*p_anim_stream)[i_word_index+24] == 0 &&
        // Must be at begin of 3D frame
        (i_actual_column == 0) && (i_actual_wall == 0) &&
        (i_command_created == 0))
    {
      i_anime_word = cmd_param_3D_frame + param_3D_frame_void;
      i_word_index = i_word_index +24;
      i_actual_wall = 5;        /* Overflow -> when process command, then
                                 * do necessary routine
                                 */

      i_command_created = 1;
    }


    /* Test if actual 3D frame is full of ones. If yes, then create special
     * command.
     */
    if( (*p_anim_stream)[i_word_index+ 0] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+ 1] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+ 2] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+ 3] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+ 4] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+ 5] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+ 6] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+ 7] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+ 8] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+ 9] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+10] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+11] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+12] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+13] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+14] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+15] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+16] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+17] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+18] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+19] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+20] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+21] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+22] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+23] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+24] == 0x7FFF &&
        // Must be at begin of 3D frame
        (i_actual_column == 0) && (i_actual_wall == 0) &&
        (i_command_created == 0))
    {
      i_anime_word = cmd_param_3D_frame + param_3D_frame_ones;
      i_word_index = i_word_index +24;
      i_actual_wall = 5;        /* Overflow -> when process command, then
                                 * do necessary routine
                                 */
      i_command_created = 1;
    }


    /* Test if actual 3D frame is same as previous. If yes, then create special
     * command.
     */
    if(
      (*p_anim_stream)[i_word_index+ 0] == (*p_anim_stream)[i_word_index-25] &&
      (*p_anim_stream)[i_word_index+ 1] == (*p_anim_stream)[i_word_index-24] &&
      (*p_anim_stream)[i_word_index+ 2] == (*p_anim_stream)[i_word_index-23] &&
      (*p_anim_stream)[i_word_index+ 3] == (*p_anim_stream)[i_word_index-22] &&
      (*p_anim_stream)[i_word_index+ 4] == (*p_anim_stream)[i_word_index-21] &&
      (*p_anim_stream)[i_word_index+ 5] == (*p_anim_stream)[i_word_index-20] &&
      (*p_anim_stream)[i_word_index+ 6] == (*p_anim_stream)[i_word_index-19] &&
      (*p_anim_stream)[i_word_index+ 7] == (*p_anim_stream)[i_word_index-18] &&
      (*p_anim_stream)[i_word_index+ 8] == (*p_anim_stream)[i_word_index-17] &&
      (*p_anim_stream)[i_word_index+ 9] == (*p_anim_stream)[i_word_index-16] &&
      (*p_anim_stream)[i_word_index+10] == (*p_anim_stream)[i_word_index-15] &&
      (*p_anim_stream)[i_word_index+11] == (*p_anim_stream)[i_word_index-14] &&
      (*p_anim_stream)[i_word_index+12] == (*p_anim_stream)[i_word_index-13] &&
      (*p_anim_stream)[i_word_index+13] == (*p_anim_stream)[i_word_index-12] &&
      (*p_anim_stream)[i_word_index+14] == (*p_anim_stream)[i_word_index-11] &&
      (*p_anim_stream)[i_word_index+15] == (*p_anim_stream)[i_word_index-10] &&
      (*p_anim_stream)[i_word_index+16] == (*p_anim_stream)[i_word_index- 9] &&
      (*p_anim_stream)[i_word_index+17] == (*p_anim_stream)[i_word_index- 8] &&
      (*p_anim_stream)[i_word_index+18] == (*p_anim_stream)[i_word_index- 7] &&
      (*p_anim_stream)[i_word_index+19] == (*p_anim_stream)[i_word_index- 6] &&
      (*p_anim_stream)[i_word_index+20] == (*p_anim_stream)[i_word_index- 5] &&
      (*p_anim_stream)[i_word_index+21] == (*p_anim_stream)[i_word_index- 4] &&
      (*p_anim_stream)[i_word_index+22] == (*p_anim_stream)[i_word_index- 3] &&
      (*p_anim_stream)[i_word_index+23] == (*p_anim_stream)[i_word_index- 2] &&
      (*p_anim_stream)[i_word_index+24] == (*p_anim_stream)[i_word_index- 1] &&
        // Must be at begin of 3D frame - and it could NOT be frame 0
        (i_actual_column == 0) && (i_actual_wall == 0) && (i_actual_frame > 0))
    {
      i_anime_word = cmd_param_3D_frame + param_3D_frame_same;
      i_word_index = i_word_index +24;
      i_actual_wall = 5;        /* Overflow -> when process command, then
                                 * do necessary routine
                                 */
      i_command_created = 1;
    }










    /* However, test if there is void 2D frame. If yes, then change
     * i_anime_word into command and, of course, increase i_word_index
     */
    if( (*p_anim_stream)[i_word_index+0] == 0x0000 &&
        (*p_anim_stream)[i_word_index+1] == 0x0000 &&
        (*p_anim_stream)[i_word_index+2] == 0x0000 &&
        (*p_anim_stream)[i_word_index+3] == 0x0000 &&
        (*p_anim_stream)[i_word_index+4] == 0x0000 &&
        (i_actual_column == 0) &&       // Must be at the begin of 2D frame
        (i_command_created == 0))
    {
      i_anime_word = cmd_param_2D_frame + param_2D_frame_void;
      i_word_index = i_word_index +4;   // And move to the next 2D frame

      // Move to next wall
      i_actual_wall++;

      i_command_created = 1;
    }


    /* Again, test if there is full 2D frame. If yes, then change
     * i_anime_word into command and, of course, increase i_word_index
     */
    if( (*p_anim_stream)[i_word_index+0] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+1] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+2] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+3] == 0x7FFF &&
        (*p_anim_stream)[i_word_index+4] == 0x7FFF &&
        (i_actual_column == 0) &&       // Must be at the begin of 2D frame
        (i_command_created == 0))
    {
      i_anime_word = cmd_param_2D_frame + param_2D_frame_ones;
      i_word_index = i_word_index +4;   // And move to the next 2D frame

      // Move to next wall
      i_actual_wall++;

      i_command_created = 1;
    }


    /* Test if actual frame is same as previous. Can work only for WALL1~WALL4.
     * Again change i_anime_word into command and, of course, increase
     * i_word_index
     */
    if( (*p_anim_stream)[i_word_index-5] == (*p_anim_stream)[i_word_index+0] &&
        (*p_anim_stream)[i_word_index-4] == (*p_anim_stream)[i_word_index+1] &&
        (*p_anim_stream)[i_word_index-3] == (*p_anim_stream)[i_word_index+2] &&
        (*p_anim_stream)[i_word_index-2] == (*p_anim_stream)[i_word_index+3] &&
        (*p_anim_stream)[i_word_index-1] == (*p_anim_stream)[i_word_index+4] &&
        // Must be at the begin of 2D frame and WALL must be greater than WALL0
        (i_actual_column == 0) && (i_actual_wall > 0) &&
        (i_command_created == 0))
    {
      i_anime_word = cmd_param_2D_frame + param_2D_frame_same;
      i_word_index = i_word_index +4;   // And move to the next 2D frame

      // Move to next wall
      i_actual_wall++;

      i_command_created = 1;
    }



    // Read word from stream -> decide if it is command or value
    if( ( i_anime_word & (0x8000) ) == 0  )
    {// If zero (use AND masking) -> data
      // Transform integer to string (HEX format)
      sprintf( c_tmp_num, "0x%04X,", i_anime_word);

      // Write number
      fprintf(file, "%s", c_tmp_num);

      i_actual_column++;

      // Test if we are on the last column
      if(i_actual_column > 4)
      {// Write line to file ; increase i_actual_wall
        fprintf(file, "\n    ");        // Write to file newline

        i_actual_column = 0;            // Set new active column to 0

        // Move to next wall
        i_actual_wall++;
        // Test if we on the last wall
        if(i_actual_wall > 4)
        {// If last wall -> write 2 newline ; increase i_actual_frame
          i_actual_frame++;
          i_actual_wall = 0;            // Set actual wall to 0

          // Write to file 2 newlines and add info about frame #
          fprintf(file, "\n\n    // Frame %d\n    ", i_actual_frame);
        }
      }
    }
    else
    {// Else word is command
      // Extract just code number and then decide....
      switch( ((i_anime_word) & 0xFF00) )
      {
      case cmd_set_pwm_r: strcpy( c_tmp_txt, "cmd_set_pwm_r"); break;
      case cmd_set_pwm_g: strcpy( c_tmp_txt, "cmd_set_pwm_g"); break;
      case cmd_set_pwm_b: strcpy( c_tmp_txt, "cmd_set_pwm_b"); break;

      case cmd_param_2D_frame: strcpy( c_tmp_txt, "cmd_param_2D_frame"); break;

      case cmd_param_3D_frame: strcpy( c_tmp_txt, "cmd_param_3D_frame"); break;

      // Case, that command not found -> all to default
      default: strcpy( c_tmp_txt, "0x8000");
      }

      // Add value and some things
      // Add value to the code
      //sprintf( c_tmp_num, " + %d", (i_anime_word)&(0xFF)>>8 );

      // So, now just write it to the file - value is written low 8 bits
      fprintf(file, "%s + %d,\n    ", c_tmp_txt, (i_anime_word)&(0xFF) );

      /* Test if we were on the last wall (for case,that was found compress
       * command -> increase wall -> now check       *
       */
      if(i_actual_wall > 4)
      {// If last wall -> write 2 newline ; increase i_actual_frame
        i_actual_frame++;
        i_actual_wall = 0;            // Set actual wall to 0

        // Write to file 2 newlines and add info about frame #
        fprintf(file, "\n\n    // Frame %d\n    ", i_actual_frame);
      }


    }


    // Move to next word
    i_word_index++;
  }


  // Close file
  fclose(file);
}










/**
 * \brief Write end of animation.
 *
 * @param i_options Options for ending animation.
 * @param p_animation_name Pointer to text array where animation name is saved
 */
void write_end_of_animation(int i_options, char *p_animation_name)
{
  // Test for input parameters
  if( (i_options > 255) || (i_options < 0))
  {
    i_options = 0;      // If input variable is out of range
    printf(""
"| ! Warning: End of animation option out of range. Set to 0 (default)       |"
"\n"
        );
  }


  FILE *file;   // Pointer to file

  // String for complete path (include filename and extension -> +2)
  char c_file_and_path[name_len + path_len +2];


  // Save string contains name of anime folder
  strcpy(c_file_and_path, generated_anime_folder);
  // Add slash and prefix anim
  strcat(c_file_and_path, "/anim_");
  // Add file name
  strcat(c_file_and_path, p_animation_name);
  // Add ".c"
  strcat(c_file_and_path, ".c");

  // Open file - .c file (append mode)
  file = fopen( c_file_and_path, "a+");

  char c_file_content[128];

  strcpy(c_file_content, ""
"    // End of animation + option\n"
"    cmd_anim_stop + "
  );

  char c_number_as_text[4];
  sprintf( c_number_as_text, "%d", i_options);

  // Transform i_slowdown_factor to string number
  strcat(c_file_content, c_number_as_text);
  strcat(c_file_content, "\n  };");

  // Write content to file
  fprintf(file, "%s", c_file_content);

  fclose(file);
}







/**
 * \brief Print a lots of newline characters, so actual screen go away
 */
void jump_out_to_next_screen(void)
{
  for(int i=0 ; i<screen_lines_max ; i++ )
  {
    printf("\n\n\n\n\n\n\n\n\n\n");
  }
}


/**
 * \brief Clear (set 0) in whole framebuffer
 * @param p_fb_data_virtual Pointer to framebuffer
 */
void clear_virtual_framebuffer(uint8_t (*p_fb_data_vitual)[5][5][5])
{
  for(int i=0 ; i<5 ; i++)
  {
    for(int j=0 ; j<5 ; j++)
    {
      for(int k=0 ; k<5 ; k++)
      {
        (*p_fb_data_vitual)[i][j][k] = 0;
      }
    }
  }
}

/**
 * \brief Set (set 1) in whole framebuffer
 * @param p_fb_data_virtual Pointer to framebuffer
 */
void set_virtual_framebuffer(uint8_t (*p_fb_data_virtual)[5][5][5])
{
  for(int i=0 ; i<5 ; i++)
  {
    for(int j=0 ; j<5 ; j++)
    {
      for(int k=0 ; k<5 ; k++)
      {
        (*p_fb_data_virtual)[i][j][k] = (1<<red_shift)|
                                        (1<<green_shift)|
                                        (1<<blue_shift);
      }

    }
  }
}





void clear_real_framebuffer(uint16_t (*p_anim_stream)[max_size_anim_stream])
{
  for(int i=0 ; i<max_size_anim_stream ; i++)
  {
    (*p_anim_stream)[i] = 0;
  }
}




void show_preview(uint8_t  (*p_fb_data_virtual)[5][5][5],
                  uint32_t i_frame_counter,
                  uint8_t  i_wall,
                  uint8_t  i_column,
                  uint8_t  i_led_level,
                  uint8_t  i_pwm_r,
                  uint8_t  i_pwm_g,
                  uint8_t  i_pwm_b,
                  float f_virtual_time)
{

  printf(""
"+---------------------------------------------------------------------------+"
"\n"
"| Frame: %9d | Wall: %d/4 | Column: %d/4 | Time: %7.2f s              |\n"
"+--------------+---+-----------++------------+--+---------------------------+"
"\n"
"| PWM red: %3d | PWM green: %3d | PWM blue: %3d |                           |"
"\n"
"+--------------+----------------+---------------+---------------------------+"
"\n"
"|              | C0  |     | C1  |     | C2  |     | C3  |     | C4  |      |"
"\n"
"|                                                                           |"
"\n"
  , i_frame_counter, i_wall, i_column, f_virtual_time,
  i_pwm_r, i_pwm_g, i_pwm_b
  );

  for(int i=4 ; i>=0 ; i--)      // led level (LED 0 ~ LED 4)
  {
    printf("|    LED %d >   ", i);

    for(int j=0 ; j<5 ; j++)    // Collumn
    {
      // If actual "window" is active
      if( (i==i_led_level) && (j==i_column))
      {
        printf("| ");
      }
      else
      { // Else actual "window" is not active
        printf("  ");
      }

      // Test if red bit is set
      if( (*p_fb_data_virtual)[i_wall][i][j] & (1<<red_shift) )
      {
        printf("R");
      }
      else
      {
        printf("-");
      }
      // Test if green bit is set
      if( (*p_fb_data_virtual)[i_wall][i][j] & (1<<green_shift) )
      {
        printf("G");
      }
      else
      {
        printf("-");
      }
      // Test if blue bit is set
      if( (*p_fb_data_virtual)[i_wall][i][j] & (1<<blue_shift) )
      {
        printf("B");
      }
      else
      {
        printf("-");
      }

      // If actual "window" is active
      if( (i==i_led_level) && (j==i_column))
      {
        printf(" |     ");
      }
      else
      {
        printf("       ");
      }
    }
    //End of line
    printf(" |\n"
"|                                                                           |"
"\n");
  }

  // End of frame
  printf(""
"+---------------------------------------------------------------------------+"
"\n"
"| Type command or data. Aviable commands:                                   |"
"\n"
"|  exit - save data (to actual frame) and exit from application             |"
"\n"
"|  zeros - clear actual frame - turn off all LEDs on actual frame           |"
"\n"
"|  ones - set actual frame - turn on all LEDs on acutal frame               |"
"\n"
"|  next - move to next wall. Actual 2D frame will be saved                  |"
"\n"
"|  back - move to previous wall. Actual 2D frame will be saved              |"
"\n"
"|  pwmr - set PWM on channel with RED LEDs. pwmg is for green and pwmb for  |"
"\n"
"|         blue channel. Value of PWM is same for whole frame.               |"
"\n"
"|  line - copy actual segment thru line                                     |"
"\n"
"|  column - copy actual segment thru column                                 |"
"\n"







"+---------------------------------------------------------------------------+"
"\n"
"| Howto type data (examples):                                               |"
"\n"
"| rgb -> turn on all LEDs in segment                                        |"
"\n"
"| r-- -> just turn on red LED                                               |"
"\n"
"| 011 -> turn green and blue LED                                            |"
"\n"
"| A   -> turn on all LEDs in segment                                        |"
"\n"
"| g   -> turn on green LED                                                  |"
"\n"




"+---------------------------------------------------------------------------+"
"\n"
"| Command line: "
  );
}
